"use strict";
const nodejs_fs_utils_1 = require("nodejs-fs-utils");
const mkdirp_1 = require("mkdirp");
const fs_1 = require("fs");
const path_1 = require("path");
const get_local_configset_name_1 = require("./get-local-configset-name");
const current_config_1 = require("./current-config");
const error_1 = require("../library/error");
const json_1 = require("../library/json");
const path_2 = require("../library/path");
const new_env_1 = require("./new-env");
const git_1 = require("../library/git");
function createConfigSet(name, global) {
    const targetPath = path_2.configSetPath(name, global || false);
    if (fs_1.existsSync(targetPath)) {
        throw new error_1.default(`target path ${targetPath} is already exists, please remove it first.`);
    }
    mkdirp_1.sync(path_1.dirname(targetPath));
    try {
        git_1.gitinit(targetPath);
        const installFile = path_1.resolve(targetPath, 'environments.json');
        json_1.writeJsonFile(installFile, {
            name: name,
            environments: {}
        });
        new_env_1.newEnvironment(targetPath, 'default', false);
        const gitignoreFile = path_1.resolve(targetPath, '.gitignore');
        fs_1.writeFileSync(gitignoreFile, `
.idea
`, 'utf-8');
        git_1.gitadd(targetPath);
        git_1.gitcommit(targetPath, 'init json env storage');
        git_1.gitbranch_rename(targetPath, 'jsonenv');
    }
    catch (e) {
        nodejs_fs_utils_1.rmdirsSync(targetPath);
        throw e;
    }
    current_config_1.setCurrentConfigSet(get_local_configset_name_1.getLocalConfigName());
    return targetPath;
}
exports.createConfigSet = createConfigSet;
//# sourceMappingURL=create-configset.js.map