"use strict";
const nodejs_fs_utils_1 = require('nodejs-fs-utils');
const fs_1 = require("fs");
const os_1 = require("os");
const path_1 = require("path");
const mkdirp_1 = require("mkdirp");
const current_config_1 = require("./current-config");
const error_1 = require("../library/error");
const path_2 = require("../library/path");
const id_file_1 = require("../library/id_file");
const git_1 = require("../library/git");
function fetchConfigSet(git_url, global, force) {
    const tempPath = path_1.join(os_1.tmpdir(), 'jenv_fetch_temp', git_url);
    if (!fs_1.existsSync(tempPath)) {
        console.error('clone to %s', tempPath);
        git_1.gitclone(tempPath, git_url, 'jsonenv');
    }
    const config = id_file_1.readIdFile(tempPath);
    const configSetName = config.name;
    // temp prepare ok
    const targetPath = path_2.configSetPath(configSetName, global || false);
    if (fs_1.existsSync(targetPath)) {
        if (!force) {
            const exists_config = id_file_1.readIdFile(targetPath);
            if (exists_config.name === configSetName) {
                force = true;
            }
        }
        if (force) {
            console.error('rm -rf %s', targetPath);
            nodejs_fs_utils_1.rmdirsSync(targetPath);
        }
        else {
            throw new error_1.default(`target path ${targetPath} is already exists, please remove it first.`);
        }
    }
    mkdirp_1.sync(path_1.dirname(targetPath));
    nodejs_fs_utils_1.moveSync(tempPath, targetPath);
    current_config_1.setCurrentConfigSet(configSetName);
    return { name: configSetName, path: targetPath };
}
exports.fetchConfigSet = fetchConfigSet;
//# sourceMappingURL=fetch-configset.js.map