"use strict";
const fs_1 = require("fs");
const json_1 = require("../library/json");
const git_1 = require("../library/git");
const path_1 = require("path");
function newEnvironment(dir, name, base, skipGit = false) {
    const targetFile = path_1.resolve(dir, `environments.json`);
    if (!fs_1.existsSync(targetFile)) {
        console.error(`error: target file ${targetFile} not exists.`);
        return false;
    }
    let def = json_1.readJsonFile(targetFile);
    if (!def.environments) {
        def.environments = {};
    }
    if (def.environments[name]) {
        console.error(`info: environment ${name} already exists.`);
        return true;
    }
    def.environments[name] = {
        "inherits": base === undefined ? 'default' : base,
    };
    json_1.writeJsonFile(targetFile, def);
    const rootFile = path_1.resolve(dir, `.root/${name}.json`);
    if (!fs_1.existsSync(rootFile)) {
        json_1.writeJsonFile(rootFile, {});
    }
    const envFile = path_1.resolve(dir, `.environment/${name}.json`);
    if (!fs_1.existsSync(envFile)) {
        json_1.writeJsonFile(envFile, {});
    }
    if (!skipGit) {
        git_1.gitadd(dir);
        git_1.gitcommit(dir, `create new env ${name}`);
    }
}
exports.newEnvironment = newEnvironment;
//# sourceMappingURL=new-env.js.map