"use strict";
const extend = require('extend');
const fs_1 = require("fs");
const path_1 = require("path");
const error_1 = require("../library/error");
const current_config_1 = require("./current-config");
const json_1 = require("../library/json");
const dts_1 = require("../library/dts");
const get_env_meta_1 = require("./get-env-meta");
const path_2 = require("../library/path");
const output_1 = require("../library/output");
const apply_global_env_1 = require("./apply-global-env");
const TEMP_FILE = path_1.resolve(process.cwd(), './.jsonenv/', `_current_result.json`);
function readEnvSync(environment) {
    const result = {
        JENV_FILE_NAME: TEMP_FILE,
        JENV_FILE_NAME_REL: TEMP_FILE.replace(process.cwd() + '', '.'),
    };
    const setName = current_config_1.getCurrentConfigSet();
    if (!setName) {
        throw new error_1.default('config set has not define, use "jenv --set" or "jenv --pull" to set it.');
    }
    const setPath = path_2.findConfigSetPath(setName);
    if (!setPath) {
        throw new error_1.default(`config set "${setName}" do not exists`);
    }
    let meta = get_env_meta_1.getEnvironmentMetaData(setName, environment);
    if (meta.abstract) {
        throw new error_1.default(`config set "${setName}" is abstract`);
    }
    const inheritList = [environment];
    if (meta.inherits) {
        while (meta.inherits) {
            inheritList.push(meta.inherits);
            meta = get_env_meta_1.getEnvironmentMetaData(setPath, meta.inherits);
        }
    }
    parseFolder(result, setPath, inheritList.reverse());
    apply_global_env_1.changeVariableNames(result);
    result.__config = {
        set: setName,
        path: setPath,
        env: environment,
        meta: meta
    };
    json_1.writeJsonFile(TEMP_FILE, result);
    dts_1.generateDefineTs(TEMP_FILE);
    return result;
}
Object.defineProperty(exports, "__esModule", { value: true });
exports.default = readEnvSync;
function getFileContent(dir, environmentList) {
    const ret = {};
    if (fs_1.existsSync(path_1.resolve(dir, '.empty'))) {
        return {};
    }
    let found = false;
    environmentList.forEach(function (environment) {
        const confFile = path_1.resolve(dir, `${environment}.json`);
        if (fs_1.existsSync(confFile)) {
            found = true;
            if (output_1.prettyPrint) {
                console.error('-> %s', confFile);
            }
            extend(ret, json_1.readJsonFile(confFile));
        }
    });
    if (!found) {
        throw new Error(`required config file "${dir}/[${environmentList.join(', ')}].json" not found.`);
    }
    return ret;
}
function parseFolder(itr, dir, environmentList, root = true) {
    if (root && fs_1.existsSync(path_1.resolve(dir, '.root'))) {
        if (fs_1.existsSync(path_1.resolve(dir, '.environment'))) {
            itr['.ENVIRONMENT'] = {};
            extend(true, itr['.ENVIRONMENT'], getFileContent(path_1.resolve(dir, '.environment'), environmentList));
            extend(true, itr, itr['.ENVIRONMENT']);
        }
        extend(true, itr, getFileContent(path_1.resolve(dir, '.root'), environmentList));
    }
    else {
        extend(true, itr, getFileContent(dir, environmentList));
    }
    fs_1.readdirSync(dir).forEach((name) => {
        if (/^\./.test(name)) {
            return;
        }
        const subFile = path_1.resolve(dir, name);
        if (fs_1.lstatSync(subFile).isDirectory()) {
            itr[name] = {};
            parseFolder(itr[name], subFile, environmentList, false);
        }
    });
}
//# sourceMappingURL=read-env.js.map