/// <reference path="../typings/index.d.ts" />
/// <reference path="../global.d.ts" />
"use strict";
require('source-map-support/register');
const usage_1 = require('./actions/usage');
const i18n_1 = require('./library/i18n');
const os_1 = require('os');
const error_1 = require('./library/error');
const read_env_1 = require('./actions/read-env');
const current_config_1 = require('./actions/current-config');
const shell_1 = require("./library/shell");
const apply_global_env_1 = require("./actions/apply-global-env");
i18n_1.default(() => {
    const args = process.argv.slice(2);
    if (!args.length) {
        throw usage_1.default();
    }
    let firstArg = args.shift();
    if (args.length === 0 && /^shell$/.test(firstArg)) {
        firstArg = os_1.platform() === 'win32' ? 'cmd.exe' : '/usr/bin/bash';
    }
    const isCommand = /^--/.test(firstArg);
    const isEnv = !isCommand && /^-/.test(firstArg);
    if (isCommand) {
        const cmd_options = {};
        const cmd_args = args.filter(function (item) {
            if (/^--/.test(item)) {
                const match = /^--(.+?)(=(.+))?$/.exec(item);
                if (!match) {
                    console.error('unknwon argument %s', item);
                    process.exit(1);
                }
                cmd_options[match[1]] = match[3] === undefined ? true : match[3];
                return false;
            }
            else if (/^-/.test(item)) {
                if (cmd_options['envName']) {
                    console.error('duplicate env argument %s', item);
                    process.exit(1);
                }
                cmd_options['envName'] = item.replace(/^-/, '');
            }
            else {
                return true;
            }
        });
        try {
            const ret = require('./run_command')(firstArg.replace(/^--/, ''), cmd_args, cmd_options);
            if (ret === 999) {
                return;
            }
            process.exit(ret);
        }
        catch (e) {
            if (e instanceof error_1.default) {
                if (e.message !== 'ignore') {
                    console.error(e.stack);
                }
                process.exit(1);
            }
            else {
                throw e;
            }
        }
    }
    else {
        let envName;
        if (isEnv) {
            envName = firstArg.replace(/^-/, '');
        }
        else {
            envName = current_config_1.getCurrentDefault();
            args.unshift(firstArg);
        }
        let config;
        try {
            config = read_env_1.default(envName);
        }
        catch (err) {
            console.error(`can't load environment "${envName}":\n    ${err.stack}`);
            process.exit(1);
        }
        apply_global_env_1.applyGlobalEnv(config);
        const ret = shell_1.default(args);
        process.exit(ret);
    }
});
//# sourceMappingURL=bin.js.map