"use strict";
const fs_1 = require("fs");
const mkdirp_1 = require("mkdirp");
const path_1 = require("path");
const json_1 = require("./json");
const error_1 = require("./error");
exports.DEFAULT_FILE = path_1.resolve(process.cwd(), './.jsonenv/default');
let env_cache;
function getCurrentConfig() {
    if (!env_cache) {
        if (fs_1.existsSync(exports.DEFAULT_FILE)) {
            env_cache = json_1.readJsonFile(exports.DEFAULT_FILE);
        }
        else {
            env_cache = {};
        }
    }
    return env_cache;
}
exports.getCurrentConfig = getCurrentConfig;
function writeCurrentEnv() {
    mkdirp_1.sync(path_1.dirname(exports.DEFAULT_FILE));
    return json_1.writeJsonFile(exports.DEFAULT_FILE, env_cache);
}
exports.writeCurrentEnv = writeCurrentEnv;
function requireCurrentEnvironment() {
    const cenv = getCurrentConfig().env;
    if (!cenv) {
        throw new error_1.default(`current environment not set. (${exports.DEFAULT_FILE})`);
    }
    return cenv;
}
exports.requireCurrentEnvironment = requireCurrentEnvironment;
function requireCurrentConfigSet() {
    const cset = getCurrentConfig().set;
    if (!cset) {
        throw new error_1.default('current configset not set. (${DEFAULT_FILE})');
    }
    return cset;
}
exports.requireCurrentConfigSet = requireCurrentConfigSet;
//# sourceMappingURL=current.js.map