"use strict";
const error_1 = require("./error");
const spawn_sync_1 = require("./spawn-sync");
const mkdirp_1 = require("mkdirp");
function gitcheck(path) {
    const ret = spawn_sync_1.nodeExecSync(`git branch --color=never`, path);
    if (!/\* jsonenv/.test(ret)) {
        throw new error_1.default(`refuse to run in path ${path}: not a git repo on "jsonenv" branch`);
    }
}
exports.gitcheck = gitcheck;
function gitpull(dir, url) {
    const arg = ['pull'];
    if (url) {
        arg.push(url);
    }
    if (!spawn_sync_1.nodeSpawnSync('git', arg, dir)) {
        throw new error_1.default(`can't run "git pull" command.`);
    }
}
exports.gitpull = gitpull;
function gitadd(dir, files = '.') {
    const ret = spawn_sync_1.nodeSpawnSync('git', ['add', files], dir);
    if (!ret) {
        throw new error_1.default('run git command failed. (see above)');
    }
}
exports.gitadd = gitadd;
function gitcommit(dir, message = 'empty commit message') {
    if (/working directory clean/.test(spawn_sync_1.nodeExecSync('git status', dir))) {
        return true;
    }
    const ret = spawn_sync_1.nodeSpawnSync('git', ['commit', '-a', '-m', message], dir);
    if (!ret) {
        throw new error_1.default('run git command failed. (see above)');
    }
}
exports.gitcommit = gitcommit;
function gitremoteurl(dir, name, branch, url) {
    if (!spawn_sync_1.nodeSpawnSync('git', ['remote', 'add', name, '--no-tags', '-t', branch, url], dir)) {
        if (!spawn_sync_1.nodeSpawnSync('git', ['remote', 'set-url', name, url], dir)) {
            throw new error_1.default('run git command failed. (see above)');
        }
    }
}
exports.gitremoteurl = gitremoteurl;
function gitremote(path) {
    return spawn_sync_1.nodeExecSync(`git remote get-url origin`, path);
}
exports.gitremote = gitremote;
function gitpush(dir, remote, branch) {
    if (!spawn_sync_1.nodeSpawnSync('git', ['push', '--set-upstream', remote, branch], dir)) {
        throw new error_1.default(`can't run "git push" command.`);
    }
}
exports.gitpush = gitpush;
function gitinit(targetPath) {
    const ret = spawn_sync_1.nodeSpawnSync('git', ['init', targetPath]);
    if (!ret) {
        throw new error_1.default('run git command failed. (see above)');
    }
}
exports.gitinit = gitinit;
function gitbranch_rename(path, newName) {
    const ret = spawn_sync_1.nodeSpawnSync('git', ['branch', '-M', newName], path);
    if (!ret) {
        throw new error_1.default('run git command failed. (see above)');
    }
}
exports.gitbranch_rename = gitbranch_rename;
function gitbranch(path, branch) {
    const ret = spawn_sync_1.nodeSpawnSync('git', ['branch', branch], path);
    if (!ret) {
        throw new error_1.default('run git command failed. (see above)');
    }
}
exports.gitbranch = gitbranch;
function gitclone(path, url, branch) {
    mkdirp_1.sync(path);
    const ret = spawn_sync_1.nodeSpawnSync('git', ['clone', '-b', branch, '--single-branch', url, '.'], path);
    if (!ret) {
        throw new error_1.default('run git command failed. (see above)');
    }
}
exports.gitclone = gitclone;
//# sourceMappingURL=git.js.map