"use strict";
const path_1 = require("path");
var osLocale = require('os-locale');
let callback = [];
function installI18N(cb) {
    if (global.t) {
        cb();
    }
    else {
        callback.push(cb);
    }
}
Object.defineProperty(exports, "__esModule", { value: true });
exports.default = installI18N;
osLocale((err, locale) => {
    if (err) {
        throw err;
    }
    locale = locale.toLowerCase().replace(/_/g, '-');
    if (locale === 'posix') {
        locale = 'en-us';
    }
    let langFile = localeFilePath(locale);
    if (!require('fs').existsSync(require('path').resolve(__dirname, langFile))) {
        console.warn(`Warn: no language file for ${locale}, fallback to en.`);
        locale = 'en-us';
        langFile = localeFilePath(locale);
    }
    global.t = getTextFn(locale, require(langFile));
    callback.forEach((cb) => {
        cb();
    });
});
function getTextFn(locale, data) {
    return (text) => {
        if (data.hasOwnProperty(text)) {
            return data[text];
        }
        else {
            console.warn(`Warn: no translate for text "${text}" in ${locale}.`);
            return text.toUpperCase();
        }
    };
}
function localeFilePath(locale) {
    return path_1.resolve(__dirname, `../../i18n/${locale}.json`);
}
//# sourceMappingURL=i18n.js.map